@@ -2,7 +2,18 @@ package Devel::Examine::Subs;
 use warnings;
 use strict;
 
-our $VERSION = '1.36';
+use Carp;
+use Data::Compare;
+use Data::Dumper;
+use Devel::Examine::Subs::Engine;
+use Devel::Examine::Subs::Preprocessor;
+use Devel::Examine::Subs::Prefilter;
+use File::Find;
+use PPI;
+use Symbol;
+use Tie::File;
+
+our $VERSION = '1.37';
 
 BEGIN {
 
@@ -19,19 +30,15 @@ BEGIN {
     }
 };
 
-use Carp;
-use Data::Compare;
-use Data::Dumper;
-use Devel::Examine::Subs::Engine;
-use Devel::Examine::Subs::Preprocessor;
-use Devel::Examine::Subs::Prefilter;
-use File::Find;
-use PPI;
-use Symbol;
-use Tie::File;
-
 sub new {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+   
+    # set up for tracing
+
+    if ($ENV{DTS_ENABLE} && $ENV{DES_TRACE}){
+        $ENV{TRACE} = 1;
+    }
+
+    trace() if $ENV{TRACE};
 
     my $self = {};
     bless $self, shift;
@@ -47,7 +54,7 @@ sub new {
     return $self;
 }
 sub run {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     my $p = shift;
@@ -72,7 +79,7 @@ sub run {
     return $struct;
 }
 sub _run_directory {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     my $p = shift;
@@ -82,7 +89,7 @@ sub _run_directory {
     my $dir = $self->{params}{file};
 
     find({wanted => sub {
-            trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+            trace() if $ENV{TRACE};
             return if ! -f;
 
             my @extensions = @{$self->{params}{extensions}};
@@ -119,7 +126,7 @@ sub _run_directory {
     return \%struct;
 }
 sub _end_of_line {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     my $file = shift;
@@ -137,7 +144,7 @@ sub _end_of_line {
     untie @tie_file;
 }
 sub _run_end {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     my $value = shift;
@@ -147,7 +154,7 @@ sub _run_end {
     return $self->{run_end};
 }
 sub _cache {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     my $file = shift if @_;
@@ -170,13 +177,13 @@ sub _cache {
     }
 }
 sub _cache_enabled {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     return $self->{params}{cache};
 }
 sub _cache_safe {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     my $value = shift;
@@ -186,14 +193,14 @@ sub _cache_safe {
     return $self->{cache_safe};
 }
 sub _params {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     my %params = @_;
     return \%params;
 }
 sub _config {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     my $p = shift;
@@ -288,7 +295,7 @@ sub _config {
     }
 }
 sub _clean_config {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     my $config_vars = shift; # href of valid params
@@ -315,7 +322,7 @@ sub _clean_config {
     }
 }
 sub _clean_core_config {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     # deletes core phase info after each run
 
@@ -332,7 +339,7 @@ sub _clean_core_config {
     }
 }
 sub _file {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
 
     my $self = shift;
@@ -390,7 +397,7 @@ sub _file {
    return $self->{params}{file};
 }
 sub _core {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
     
     my $self = shift;
 
@@ -484,7 +491,7 @@ sub _core {
     return $subs;
 }
 sub _subs {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
     
     my $self = shift;
     
@@ -557,7 +564,7 @@ sub _subs {
     return \%subs;
 }
 sub _pre_proc {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     my $p = shift;
@@ -614,7 +621,7 @@ sub _pre_proc {
     return $cref;
 }
 sub _pre_filter {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     my $p = shift;
@@ -691,7 +698,7 @@ sub _pre_filter {
     return @pre_filters;
 }
 sub _engine {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     my $p = shift;
@@ -746,7 +753,7 @@ sub _engine {
     return $cref;
 }
 sub pre_procs {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     my $module = $self->{namespace} . "::Preprocessor";
@@ -760,7 +767,7 @@ sub pre_procs {
     return @pre_procs;
 }
 sub pre_filters {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     my $module = $self->{namespace} . "::Prefilter";
@@ -774,7 +781,7 @@ sub pre_filters {
     return @pre_filters;
 }
 sub engines {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     my $module = $self->{namespace} . "::Engine";
@@ -788,7 +795,7 @@ sub engines {
     return @engines;
 }
 sub has {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -799,7 +806,7 @@ sub has {
     $self->run($p);
 }
 sub missing {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -809,7 +816,7 @@ sub missing {
     $self->run($p);
 }
 sub all {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -819,7 +826,7 @@ sub all {
     $self->run($p);
 }
 sub lines {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -833,7 +840,7 @@ sub lines {
     $self->run($p);
 }
 sub module {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -849,7 +856,7 @@ sub module {
     $self->run($p);
 }
 sub objects {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -860,7 +867,7 @@ sub objects {
     $self->run($p);
 }
 sub search_replace {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -873,7 +880,7 @@ sub search_replace {
     $self->run($p);
 }
 sub inject {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
     my $self = shift;
     my $p = $self->_params(@_);
 
@@ -887,7 +894,7 @@ sub inject {
     $self->run($p);
 }
 sub remove {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -898,7 +905,7 @@ sub remove {
     $self->run($p);
 }
 sub inject_after {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     my $p = $self->_params(@_);
@@ -915,7 +922,7 @@ sub inject_after {
     $self->run($p);
 }
 sub add_functionality {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
     
     my $self = shift;
     my $p = $self->_params(@_);
@@ -939,7 +946,7 @@ sub add_functionality {
 
     my %dt = (
             engine => sub {
-                        trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+                        trace() if $ENV{TRACE};
                         return $in_prod
                         ? $INC{'Devel/Examine/Subs/Engine.pm'}
                         : 'lib/Devel/Examine/Subs/Engine.pm';
@@ -981,12 +988,13 @@ sub add_functionality {
     push @TIE_file, @code;
 }
 sub valid_params {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     return %{$self->{valid_params}};
 }
-sub _pod{} #vim placeholder 1; 
+sub _pod{} #vim placeholder 
+1; 
 __END__
 
 =head1 NAME
