@@ -5,7 +5,7 @@ use warnings;
 use Carp;
 use Data::Dumper;
 
-our $VERSION = '1.36';
+our $VERSION = '1.37';
 
 BEGIN {
 
@@ -22,7 +22,7 @@ BEGIN {
 };
 
 sub new {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = {};
     bless $self, shift;
@@ -34,7 +34,7 @@ sub new {
     return $self;
 }
 sub _dt {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
 
@@ -51,7 +51,7 @@ sub _dt {
     return $dt;
 }
 sub exists {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     my $self = shift;
     my $string = shift;
@@ -64,10 +64,10 @@ sub exists {
     }
 }
 sub subs {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
     
     return sub {
-        trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+        trace() if $ENV{TRACE};
 
         my $p = shift;
         my $struct = shift;
@@ -99,10 +99,10 @@ sub subs {
     };
 }
 sub file_lines_contain {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     return sub {
-        trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+        trace() if $ENV{TRACE};
 
         my $p = shift;
         my $struct = shift;
@@ -140,10 +140,10 @@ sub file_lines_contain {
     };
 }
 sub end_of_last_sub {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
     
     return sub {
-        trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+        trace() if $ENV{TRACE};
         
         my $p = shift;
         my $struct = shift;
@@ -161,22 +161,22 @@ sub end_of_last_sub {
     };
 }
 sub _test {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     return sub {
-        trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+        trace() if $ENV{TRACE};
         my $p = shift;
         my $struct = shift;
         return $struct;
     };
 }
 sub objects {
-    trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+    trace() if $ENV{TRACE};
 
     # uses 'subs' pre_filter
 
     return sub {
-        trace() if $ENV{DTS_ENABLE} && $ENV{DES_TRACE};
+        trace() if $ENV{TRACE};
 
         my $p = shift;
         my $struct = shift;
